==> cloudpos-common-classes-1.7-20210802.050430-283.jar: com/floreantpos/constants/RestConstants.java <==
package com.floreantpos.constants;

public class RestConstants {

	/*
	 * map params
	 */
	public static final String STORE_NAME = "store_name"; //$NON-NLS-1$
	public static final String TERMINAL_ID = "terminalId"; //$NON-NLS-1$
	public static final String DEVICE_ID = "device_id"; //$NON-NLS-1$
	public static final String OUTLET_ID = "outlet_id";
	public static final String CUSTOMER_ID = "customer_id"; //$NON-NLS-1$
	public static final String USER_EMAIL = "user_email"; //$NON-NLS-1$
	public static final String PASSWORD = "password"; //$NON-NLS-1$
	public static final String LAST_UPDATE_TIME = "lastUpdateTime"; //$NON-NLS-1$
	public static final String CREATE_SAMPLE_DATA = "create_sample_data";

	/*
	 * web service params
	 */
	public static final String WEB_SERVICE_URL = "web.service.url"; //$NON-NLS-1$
	public static final String WEB_SERVICE_SCHEMA_NAME = "web.service.schema"; //$NON-NLS-1$
	public static final String WEB_LOGIN_USER_NAME = "web.service.username"; //$NON-NLS-1$
	public static final String WEB_LOGIN_USER_PASSWORD = "web.service.password"; //$NON-NLS-1$
	public static final String WEB_LOGIN_CUSTOMER_ID = "web.service.customer.id"; //$NON-NLS-1$

	public static final String WEB_URL = "https://siiopa.com/console"; //$NON-NLS-1$
	public static final String URL_SERVICE_STORE_REGISTER = "/service/store/register"; //$NON-NLS-1$
	public static final String URL_SERVICE_STORE_LOGIN = "/service/store/login"; //$NON-NLS-1$
	public static final String URL_SERVICE_DATA_STORE = "/service/data/store/"; //$NON-NLS-1$

	//client register params
	public static final String REGISTER_DATA = "register_data";
	public static final String BUSINESS_NAME = "businessName";
	public static final String BUSINESS_TYPE = "businessType";
	public static final String CURRENCY_NAME = "currencyName";
	public static final String CURRENCY_CODE = "currencyCode";
	public static final String CURRENCY_SYMBOL = "currencySymbol";
	public static final String CURRENCY_EX_RATE = "currencyExRate";
	public static final String ADDRESS_LINE_1 = "addressLine1";
	public static final String ADDRESS_LINE_2 = "addressLine2";
	public static final String ADDRESS_LINE_3 = "addressLine3";
	public static final String COUNTRY = "country";
	public static final String STATE = "state";
	public static final String CITY = "city";
	public static final String ZIP_CODE = "zipCode";
	public static final String PHONE = "phone";
	public static final String TAX_RATE = "taxRate";

}

==> cloudpos-common-classes-1.9-20250825.123723-215.jar: com/floreantpos/constants/RestConstants.java <==
package com.floreantpos.constants;

public class RestConstants {

	/*
	 * map params
	 */
	public static final String STORE_NAME = "store_name"; //$NON-NLS-1$
	public static final String TERMINAL_ID = "terminalId"; //$NON-NLS-1$
	public static final String DEVICE_ID = "device_id"; //$NON-NLS-1$
	public static final String OUTLET_ID = "outlet_id";
	public static final String CUSTOMER_ID = "customer_id"; //$NON-NLS-1$
	public static final String USER_EMAIL = "user_email"; //$NON-NLS-1$
	public static final String PASSWORD = "password"; //$NON-NLS-1$
	public static final String LAST_UPDATE_TIME = "lastUpdateTime"; //$NON-NLS-1$
	public static final String CREATE_SAMPLE_DATA = "create_sample_data";
	public static final String PRODUCT_ID = "product_id"; //$NON-NLS-1$
	public static final String PRODUCT_NAME = "product_name"; //$NON-NLS-1$

	/*
	 * web service params
	 */
	public static final String WEB_SERVICE_URL = "web.service.url"; //$NON-NLS-1$
	public static final String WEB_SERVICE_SCHEMA_NAME = "web.service.schema"; //$NON-NLS-1$
	public static final String WEB_LOGIN_USER_NAME = "web.service.username"; //$NON-NLS-1$
	public static final String WEB_LOGIN_USER_PASSWORD = "web.service.password"; //$NON-NLS-1$
	public static final String WEB_LOGIN_CUSTOMER_ID = "web.service.customer.id"; //$NON-NLS-1$

	public static final String WEB_URL = "https://siiopa.com/console"; //$NON-NLS-1$
	public static final String URL_SERVICE_STORE_REGISTER = "/service/store/register"; //$NON-NLS-1$
	public static final String URL_SERVICE_STORE_LOGIN = "/service/store/login"; //$NON-NLS-1$
	public static final String URL_SERVICE_DATA_STORE = "/service/data/store/"; //$NON-NLS-1$

	//client register params
	public static final String REGISTER_DATA = "register_data";
	public static final String BUSINESS_NAME = "businessName";
	public static final String BUSINESS_TYPE = "businessType";
	public static final String CURRENCY_NAME = "currencyName";
	public static final String CURRENCY_CODE = "currencyCode";
	public static final String CURRENCY_SYMBOL = "currencySymbol";
	public static final String CURRENCY_EX_RATE = "currencyExRate";
	public static final String ADDRESS_LINE_1 = "addressLine1";
	public static final String ADDRESS_LINE_2 = "addressLine2";
	public static final String ADDRESS_LINE_3 = "addressLine3";
	public static final String COUNTRY = "country";
	public static final String STATE = "state";
	public static final String CITY = "city";
	public static final String ZIP_CODE = "zipCode";
	public static final String PHONE = "phone";
	public static final String TAX_RATE = "taxRate";

}
